@@ -25,18 +25,20 @@ mvnrnd_wrap <- function(a, b, mu, NN, veccObj, N, verbose = 0) {
       )
       ret$jac_grad
     },
-    method = "L-BFGS-B",
+    method = "BFGS",
     veccCondMeanVarObj = veccObj,
     a = a, b = b, mu = mu, verbose = verbose,
-    lower = c(a, rep(-Inf, n)), upper = c(b, rep(Inf, n)),
-    control = list(maxit = 500)
+    control = list(maxit = 1500, abstol = 1e-6)
   )
+  cat("Gradient norm at the optimal beta is", 
+    sqrt(2 * solv_idea_5_sp$value), "\n")
   if (verbose) {
-    cat(
-      "Gradient norm at the optimal beta is", sqrt(2 * solv_idea_5_sp$value),
-      "\n"
-    )
+    cat("Gradient norm significantly larger than zero indicates",
+        "suboptimal proposal density and",
+        "potentially wrong upper bound for reject sampling", "\n"
+    )  
   }
+  
   if (any(solv_idea_5_sp$par[1:n] < a) ||
     any(solv_idea_5_sp$par[1:n] > b)) {
     warning("Optimal x is outside the integration region during minmax tilting\n")
@@ -44,34 +46,34 @@ mvnrnd_wrap <- function(a, b, mu, NN, veccObj, N, verbose = 0) {
   x_star <- solv_idea_5_sp$par[1:n]
   beta <- solv_idea_5_sp$par[(n + 1):(2 * n)]
   # 2nd opt for finding x_star ---------------------------
-  solv_xstar <- stats::optim(
-    x_star,
-    fn = function(x, ...) {
-      val <- -psi_wrapper(x, ...)
-      if (is.infinite(val)) {
-        return(1e20)
-      } else {
-        return(val)
-      }
-    },
-    gr = function(x, ...) {
-      -dpsi_dx(x, ...)
-    },
-    method = "L-BFGS-B",
-    beta = beta,
-    veccCondMeanVarObj = veccObj,
-    a = a, b = b, mu = mu, NN = NN,
-    lower = c(a, rep(-Inf, n)), upper = c(b, rep(Inf, n)),
-    control = list(maxit = 500)
-  )
-  if (verbose) {
-    cat("Psi value is", -solv_xstar$value, "\n")
-  }
-  if (any(solv_xstar$par < a) ||
-    any(solv_xstar$par > b)) {
-    warning("Optimal x is outside the integration region during minmax tilting\n")
-  }
-  x_star <- solv_xstar$par
+  # solv_xstar <- stats::optim(
+  #   x_star,
+  #   fn = function(x, ...) {
+  #     val <- -psi_wrapper(x, ...)
+  #     if (is.infinite(val)) {
+  #       return(1e20)
+  #     } else {
+  #       return(val)
+  #     }
+  #   },
+  #   gr = function(x, ...) {
+  #     -dpsi_dx(x, ...)
+  #   },
+  #   method = "L-BFGS-B",
+  #   beta = beta,
+  #   veccCondMeanVarObj = veccObj,
+  #   a = a, b = b, mu = mu, NN = NN,
+  #   lower = c(a, rep(-Inf, n)), upper = c(b, rep(Inf, n)),
+  #   control = list(maxit = 500)
+  # )
+  # if (verbose) {
+  #   cat("Psi value is", -solv_xstar$value, "\n")
+  # }
+  # if (any(solv_xstar$par < a) ||
+  #   any(solv_xstar$par > b)) {
+  #   warning("Optimal x is outside the integration region during minmax tilting\n")
+  # }
+  # x_star <- solv_xstar$par
   # psi_star --------------------------------------
   psi_star <- psi_wrapper(x_star,
     beta = beta,
